# eric7.Plugins.VcsPlugins.vcsMercurial.HgAnnotateDialog

Module implementing a dialog to show the output of the hg annotate command.

### Global Attributes

None

### Classes

HgAnnotateDialog | Class implementing a dialog to show the output of the hg annotate command.

### Functions

None

## HgAnnotateDialog

Class implementing a dialog to show the output of the hg annotate command.

### Derived from

QDialog, Ui_HgAnnotateDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgAnnotateDialog | Constructor
__buildSkipList | Private method to build a program arguments list of changesets to be skipped.
__finish | Private slot called when the process finished or the user pressed the button.
__generateItem | Private method to generate an annotate item in the annotation list.
__processOutputLine | Private method to process the lines of output.
__resizeColumns | Private method to resize the list columns.
__showError | Private slot to show some error.
closeEvent | Protected slot implementing a close event handler.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
start | Public slot to start the annotate command.

### Static Methods

None

#### HgAnnotateDialog (Constructor)

HgAnnotateDialog(vcs, parent=None)

Constructor

vcs (Hg)
  reference to the vcs object
parent (QWidget)
  parent widget

#### HgAnnotateDialog.__buildSkipList

__buildSkipList(skiplist)

Private method to build a program arguments list of changesets to be skipped.

skiplist (str)
  name of a skip list file

Return:
  list of arguments

Return Type:
  list of str

#### HgAnnotateDialog.__finish

__finish()

Private slot called when the process finished or the user pressed the button.

#### HgAnnotateDialog.__generateItem

__generateItem(marker, revision, changeset, author, date, text)

Private method to generate an annotate item in the annotation list.

marker (str)
  marker character for skipped revisions
revision (str)
  revision string
changeset (str)
  changeset string
author (str)
  author of the change
date (str)
  date of the change
text (str)
  text of the change

#### HgAnnotateDialog.__processOutputLine

__processOutputLine(line)

Private method to process the lines of output.

line (str)
  output line to be processed

#### HgAnnotateDialog.__resizeColumns

__resizeColumns()

Private method to resize the list columns.

#### HgAnnotateDialog.__showError

__showError(out)

Private slot to show some error.

out (str)
  error to be shown

#### HgAnnotateDialog.closeEvent

closeEvent(e)

Protected slot implementing a close event handler.

e (QCloseEvent)
  close event

#### HgAnnotateDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### HgAnnotateDialog.start

start(fn, skiplist="")

Public slot to start the annotate command.

fn (str)
  filename to show the annotation for
skiplist (str)
  name of a skip list file

Up